@@ -48,12 +48,12 @@ sub new {
     }
     $self->finish;
     $self->_private_attributes({
-        'id'        => 0+ $self,
-        'st'        => $sth->_private_attributes({'Iterator' => $self}),
-        'bindvals'  => [@bindvals],
-        'callbacks' => $callbacks,
-        'slice'     => $self->_slice->{'Slice'},
-        'maxrows'   => $self->_maxrows->{'MaxRows'},
+        id        => 0+ $self,
+        st        => $sth->_private_attributes({Iterator => $self}),
+        bindvals  => [@bindvals],
+        callbacks => $callbacks,
+        slice     => $self->_slice->{Slice},
+        maxrows   => $self->_maxrows->{MaxRows},
     });
     return do {$_ = $self};
 }
@@ -85,24 +85,24 @@ sub count_all {
 
 sub execute {
     my($attr, $self) = shift->_private_attributes;
-    my $sth = $attr->{'st'};
+    my $sth = $attr->{st};
     return
       unless $sth;
     $self->reset
-      if $attr->{'executed'} || $attr->{'finished'};
-    $attr->{'executed'} = !!1;
-    if (defined($sth->execute(@_ ? @_ : @{$attr->{'bindvals'}}))) {
-        $attr->{'executed'}  = !!1;
-        $attr->{'row_count'} = 0;
-        if ($sth->{'NUM_OF_FIELDS'}) {
+      if $attr->{executed} || $attr->{finished};
+    $attr->{executed} = !!1;
+    if (defined($sth->execute(@_ ? @_ : @{$attr->{bindvals}}))) {
+        $attr->{executed}  = !!1;
+        $attr->{row_count} = 0;
+        if ($sth->{NUM_OF_FIELDS}) {
             my $count = $self->_fetch;
-            $attr->{'finished'} = !$count;
+            $attr->{finished} = !$count;
             return do {$_ = $count || '0E0'};
         }
-        $attr->{'finished'} = !!1;
+        $attr->{finished} = !!1;
         return do {$_ = '0E0'};
     }
-    $attr->{'finished'} = !!1;
+    $attr->{finished} = !!1;
     return do {$_ = undef};
 }
 
@@ -114,10 +114,10 @@ sub find {
     my $row;
     if ($self->execute(@_)) {
         if ($row = $self->_fetch_row()) {
-            $attr->{'row_count'} = 1;
+            $attr->{row_count} = 1;
         }
         else {
-            $attr->{'row_count'} = 0;
+            $attr->{row_count} = 0;
         }
         $self->reset();
     }
@@ -127,28 +127,28 @@ sub find {
 
 sub finish {
     my($attr, $self) = shift->_private_attributes;
-    if ($attr->{'st'}) {
-        $attr->{'st'}->finish
-          if $attr->{'st'}{'Active'};
+    if ($attr->{st}) {
+        $attr->{st}->finish
+          if $attr->{st}{Active};
     }
-    $attr->{'finished'}     = !!0;
-    $attr->{'executed'}     = !!0;
-    $attr->{'rows_fetched'} = 0;
-    $attr->{'buffer'}       = undef;
-    $attr->{'buf_inc'}      = DEFAULT_MAXROWS;
-    $attr->{'buf_mul'}      = BUF_MULT && BUF_MULT < 11 ? BUF_MULT : 0;
-    $attr->{'buf_lim'}      = BUF_MAXROWS || $attr->{'buf_inc'};
+    $attr->{finished}     = !!0;
+    $attr->{executed}     = !!0;
+    $attr->{rows_fetched} = 0;
+    $attr->{buffer}       = undef;
+    $attr->{buf_inc}      = DEFAULT_MAXROWS;
+    $attr->{buf_mul}      = BUF_MULT && BUF_MULT < 11 ? BUF_MULT : 0;
+    $attr->{buf_lim}      = BUF_MAXROWS || $attr->{buf_inc};
     return do {$_ = $self};
 }
 
 
 sub first {
     my($attr, $self) = shift->_private_attributes;
-    if (@_ || $attr->{'executed'} || $attr->{'st'}{'Active'}) {
+    if (@_ || $attr->{executed} || $attr->{st}{Active}) {
         $self->reset(@_);
     }
     my $row = $self->_fetch_row;
-    $attr->{'row_count'} = 1
+    $attr->{row_count} = 1
       if $row;
     return do {$_ = $row};
 }
@@ -164,38 +164,38 @@ sub iterate {
 
 sub _transform {
     my $self = shift;
-    return transform($self->_private_attributes->{'callbacks'}, @_);
+    return transform($self->_private_attributes->{callbacks}, @_);
 }
 
 
 sub _auto_manage_maxrows {
     my($attr, $self) = shift->_private_attributes;
     return
-      unless my $limit = $attr->{'buf_lim'};
+      unless my $limit = $attr->{buf_lim};
     my $dirty;
-    my $maxrows = $attr->{'maxrows'};
+    my $maxrows = $attr->{maxrows};
     my $new_mr  = do {
-        if (my $mul = $attr->{'buf_mul'}) {
+        if (my $mul = $attr->{buf_mul}) {
             if ($mul > 1) {
                 $dirty = !!1;
                 $maxrows * $mul;
             }
             else {
-                if (my $inc = $attr->{'buf_inc'}) {
+                if (my $inc = $attr->{buf_inc}) {
                     $dirty = !!1;
                     $maxrows + $inc;
                 }
             }
         }
         else {
-            if (my $inc = $attr->{'buf_inc'}) {
+            if (my $inc = $attr->{buf_inc}) {
                 $dirty = !!1;
                 $maxrows + $inc;
             }
         }
     };
     if ($dirty && $new_mr <= $limit) {
-        $attr->{'maxrows'} = $new_mr;
+        $attr->{maxrows} = $new_mr;
     }
     return $dirty;
 }
@@ -244,41 +244,41 @@ sub _auto_manage_maxrows {
 sub _fetch {
     my($attr, $self) = shift->_private_attributes;
     my($sth, $slice, $maxrows, $buf_lim) = @{$attr}{qw/st slice maxrows buf_lim/};
-    unless ($sth && $sth->{'Active'}) {
-        $attr->{'finished'} = !!1;
+    unless ($sth && $sth->{Active}) {
+        $attr->{finished} = !!1;
         return;
     }
     my $r = $sth->fetchall_arrayref($slice, $maxrows || 1);
     my $c = $r ? @{$r} : 0;
     unless ($c) {
-        $attr->{'finished'} = !!1;
+        $attr->{finished} = !!1;
         return 0;
     }
-    if ($attr->{'buffer'}) {
-        $attr->{'buffer'} = [@{$attr->{'buffer'}}, @{$r}];
+    if ($attr->{buffer}) {
+        $attr->{buffer} = [@{$attr->{buffer}}, @{$r}];
     }
     else {
-        $attr->{'buffer'} = $r;
+        $attr->{buffer} = $r;
     }
     if ($c == $maxrows && $maxrows < $buf_lim) {
         ($maxrows, $buf_lim) = @{$attr}{qw/maxrows buf_lim/}
           if $self->_auto_manage_maxrows;
     }
-    return do {$attr->{'rows_fetched'} += $c};
+    return do {$attr->{rows_fetched} += $c};
 }
 
 
 sub _is_empty {
     my $attr = shift->_private_attributes;
-    return !@{$attr->{'buffer'}};
+    return !@{$attr->{buffer}};
 }
 
 
 sub _no_more_rows {
     my($attr, $self) = shift->_private_attributes;
     $self->execute
-      unless $attr->{'executed'};
-    return $attr->{'finished'};
+      unless $attr->{executed};
+    return $attr->{finished};
 }
 
 
@@ -288,11 +288,11 @@ sub _fetch_row {
       if $self->_no_more_rows;
     return
       if $self->_is_empty && !$self->_fetch;
-    my($head, @tail) = @{$attr->{'buffer'}};
-    $attr->{'buffer'}     = \@tail;
-    $attr->{'row_count'} += 1;
+    my($head, @tail) = @{$attr->{buffer}};
+    $attr->{buffer}     = \@tail;
+    $attr->{row_count} += 1;
     return $self->_transform($head)
-      if @{$attr->{'callbacks'}};
+      if @{$attr->{callbacks}};
     return $head;
 }
 
@@ -309,11 +309,11 @@ sub remaining {
     my($attr, $self) = shift->_private_attributes;
     my @rows;
     unless ($self->_no_more_rows) {
-        until ($attr->{'finished'}) {
+        until ($attr->{finished}) {
             push @rows, $self->_fetch_row;
         }
-        $attr->{'row_count'} += scalar(@rows);
-        $self->reset if $attr->{'row_count'};
+        $attr->{row_count} += scalar(@rows);
+        $self->reset if $attr->{row_count};
     }
     return @rows
       if wantarray;
@@ -325,33 +325,33 @@ sub _maxrows {
     my $self = shift;
     throw E_BAD_MAXROWS
       if ref($_[0]);
-    $self->{'MaxRows'} = int(shift || DEFAULT_MAXROWS);
-    return $self->_private_attributes({'maxrows' => $self->{'MaxRows'}});
+    $self->{MaxRows} = int(shift || DEFAULT_MAXROWS);
+    return $self->_private_attributes({maxrows => $self->{MaxRows}});
 }
 
 
 sub _slice {
     my $self = shift;
     unless (@_) {
-        $self->{'Slice'} = DEFAULT_SLICE
-          unless defined($self->{'Slice'});
-        return $self->_private_attributes({'slice' => $self->{'Slice'}});
+        $self->{Slice} = DEFAULT_SLICE
+          unless defined($self->{Slice});
+        return $self->_private_attributes({slice => $self->{Slice}});
     }
     if (defined($_[0])) {
         if (UNIVERSAL::isa($_[0], 'ARRAY')) {
-            $self->{'Slice'} = [];
+            $self->{Slice} = [];
         }
         elsif (UNIVERSAL::isa($_[0], 'HASH')) {
-            $self->{'Slice'} = {};
+            $self->{Slice} = {};
         }
         else {
             throw E_BAD_SLICE;
         }
     }
     else {
-        $self->{'Slice'} = DEFAULT_SLICE;
+        $self->{Slice} = DEFAULT_SLICE;
     }
-    return $self->_private_attributes({'slice' => $self->{'Slice'}});
+    return $self->_private_attributes({slice => $self->{Slice}});
 }
 
 
@@ -387,10 +387,10 @@ sub single {
         whine W_MORE_ROWS
           if $count > 1;
         if ($row = $self->_fetch_row()) {
-            $attr->{'row_count'} = 1;
+            $attr->{row_count} = 1;
         }
         else {
-            $attr->{'row_count'} = 0;
+            $attr->{row_count} = 0;
         }
         $self->reset();
     }
@@ -416,11 +416,11 @@ sub DESTROY {
 
 BEGIN {
     *results          = *rs           = sub {shift->sth->rs(@_)};
-    *statement_handle = *sth          = sub {shift->_private_attributes->{'st'}};
-    *done             = *finished     = sub {shift->_private_attributes->{'finished'}};
-    *not_done         = *not_finished = sub {!shift->_private_attributes->{'finished'}};
-    *not_pending      = *executed     = sub {shift->_private_attributes->{'executed'}};
-    *pending          = *not_executed = sub {!shift->_private_attributes->{'executed'}};
+    *statement_handle = *sth          = sub {shift->_private_attributes->{st}};
+    *done             = *finished     = sub {shift->_private_attributes->{finished}};
+    *not_done         = *not_finished = sub {!shift->_private_attributes->{finished}};
+    *not_pending      = *executed     = sub {shift->_private_attributes->{executed}};
+    *pending          = *not_executed = sub {!shift->_private_attributes->{executed}};
 }
 
 1;
